% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rankingEdgeR.R
\name{edgeRranking}
\alias{edgeRranking}
\alias{edgeRranking,matrix-method}
\alias{edgeRranking,DataFrame-method}
\alias{edgeRranking,MultiAssayExperiment-method}
\title{Feature Ranking Based on Differential Expression for Count Data}
\usage{
\S4method{edgeRranking}{matrix}(countsTrain, classesTrain, ...)

\S4method{edgeRranking}{DataFrame}(
  countsTrain,
  classesTrain,
  normFactorsOptions = NULL,
  dispOptions = NULL,
  fitOptions = NULL,
  verbose = 3
)

\S4method{edgeRranking}{MultiAssayExperiment}(countsTrain, targets = NULL, ...)
}
\arguments{
\item{countsTrain}{Either a \code{\link{matrix}}, \code{\link{DataFrame}} or
\code{\link{MultiAssayExperiment}} containing the unnormalised counts.
For a \code{matrix} or \code{\link{DataFrame}}, the rows are samples, and the columns
are features, unlike the convention used in edgeR.}

\item{...}{Variables not used by the \code{matrix} nor the
\code{MultiAssayExperiment} method which are passed into and used by the
\code{DataFrame} method.}

\item{classesTrain}{A vector of class labels of class \code{\link{factor}} of the
same length as the number of samples in \code{countsTrain} if it is a
\code{\link{matrix}} or a \code{\link{DataFrame}} or a character vector of
length 1 containing the column name in \code{countsTrain} if it is a
\code{\link{DataFrame}} or the column name in \code{colData(counts)} if
\code{countsTrain} is a \code{\link{MultiAssayExperiment}}. If a column name,
that column will be removed before training.}

\item{normFactorsOptions}{A named \code{list} of any options to be passed to
\code{\link[edgeR]{calcNormFactors}}.}

\item{dispOptions}{A named \code{list} of any options to be passed to
\code{\link[edgeR]{estimateDisp}}.}

\item{fitOptions}{A named \code{list} of any options to be passed to
\code{\link[edgeR]{glmFit}}.}

\item{verbose}{Default: 3. A number between 0 and 3 for the amount of
progress messages to give.  This function only prints progress messages if
the value is 3.}

\item{targets}{If \code{countsTrain} is a \code{MultiAssayExperiment}, the
names of the data tables of counts to be used.}
}
\value{
A vector or data frame (if \code{MultiAssayExperiment} input) of
features, from the most promising features in the first position to the
least promising feature in the last position.
}
\description{
Performs a differential expression analysis between classes and ranks the
features based on test statistics. The data may have overdispersion and this
is modelled.
}
\details{
The differential expression analysis follows the standard
\code{\link[edgeR]{edgeR}} steps of estimating library size normalisation
factors, calculating dispersion, in this case robustly, and then fitting a
generalised linear model followed by a likelihood ratio test.

Data tables which consist entirely of non-numeric data cannot be analysed.
}
\examples{

  if(require(parathyroidSE) && require(PoiClaClu))
  {
    data(parathyroidGenesSE)
    expression <- assays(parathyroidGenesSE)[[1]] # Genes in rows, samples in columns.
    sampleNames <- paste("Sample", 1:ncol(parathyroidGenesSE))
    colnames(expression) <- sampleNames
    DPN <- which(colData(parathyroidGenesSE)[, "treatment"] == "DPN")
    control <- which(colData(parathyroidGenesSE)[, "treatment"] == "Control")
    expression <- expression[, c(control, DPN)]
    classes <- factor(rep(c("Contol", "DPN"), c(length(control), length(DPN))))
    expression <- expression[rowSums(expression > 1000) > 8, ] # Make small data set.
    
    # ClassifyR is using the convention of samples in rows and features in columns.
    ranked <- edgeRranking(t(expression), classes)
                                        
    head(ranked)
    plotFeatureClasses(t(expression), classes, "ENSG00000044574",
                       dotBinWidth = 500, xAxisLabel = "Unnormalised Counts")
  }

}
\references{
edgeR: a Bioconductor package for differential expression
analysis of digital gene expression data, Mark D. Robinson, Davis McCarthy,
and Gordon Smyth, 2010, \emph{Bioinformatics}, Volume 26 Issue 1,
\url{https://academic.oup.com/bioinformatics/article/26/1/139/182458}.
}
\author{
Dario Strbenac
}
