% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rankingLimma.R
\name{limmaRanking}
\alias{limmaRanking}
\alias{limmaRanking,matrix-method}
\alias{limmaRanking,DataFrame-method}
\alias{limmaRanking,MultiAssayExperiment-method}
\title{Ranking of Differentially Abundant Features}
\usage{
\S4method{limmaRanking}{matrix}(measurementsTrain, classesTrain, ...)

\S4method{limmaRanking}{DataFrame}(measurementsTrain, classesTrain, ..., verbose = 3)

\S4method{limmaRanking}{MultiAssayExperiment}(measurementsTrain, targets = NULL, classesTrain, ...)
}
\arguments{
\item{measurementsTrain}{Either a \code{\link{matrix}}, \code{\link{DataFrame}}
or \code{\link{MultiAssayExperiment}} containing the training data. For a
\code{matrix} or \code{\link{DataFrame}}, the rows are samples, and the columns are features.
If of type \code{\link{DataFrame}} or \code{\link{MultiAssayExperiment}}, the data set is subset
to only those features of type \code{numeric}.}

\item{...}{Variables not used by the \code{matrix} nor the
\code{MultiAssayExperiment} method which are passed into and used by the
\code{DataFrame} method or optional settings that are passed to
\code{\link[limma]{lmFit}}.}

\item{classesTrain}{A vector of class labels of class \code{\link{factor}} of the
same length as the number of samples in \code{measurements}.}

\item{verbose}{Default: 3. A number between 0 and 3 for the amount of
progress messages to give.  This function only prints progress messages if
the value is 3.}

\item{targets}{Names of data tables to be combined into a single table and
used in the analysis.}
}
\value{
A vector or data frame (if \code{MultiAssayExperiment} input) of
features, from the most promising features in the first position to the
least promising feature in the last position.
}
\description{
Uses a moderated F-test with empirical Bayes shrinkage to rank
differentially expressed features based on differences of means. This means
it works when there are three or more classes.
}
\details{
This ranking method looks for changes in means and uses a moderated F-test
to do so.
}
\examples{

  #if(require(sparsediscrim))
  #{
    # Genes 76 to 100 have differential expression.
    genesMatrix <- sapply(1:100, function(sample) rnorm(25, 9, 0.3))
    genesMatrix <- rbind(genesMatrix, t(sapply(1:25, function(sample)
                                      c(rnorm(75, 9, 0.3), rnorm(25, 14, 0.3)))))
    classes <- factor(rep(c("Poor", "Good"), each = 25))
    rownames(genesMatrix) <- paste("Sample", 1:nrow(genesMatrix))
    colnames(genesMatrix) <- paste("Gene", 1:ncol(genesMatrix))
    
    ranked <- limmaRanking(genesMatrix, classes)
    head(ranked)                           
  #}

}
\references{
Limma: linear models for microarray data, Gordon Smyth, 2005,
In: Bioinformatics and Computational Biology Solutions using R and
Bioconductor, Springer, New York, pages 397-420.
}
\author{
Dario Strbenac
}
