% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/previousSelection.R
\name{previousSelection}
\alias{previousSelection}
\alias{previousSelection,matrix-method}
\alias{previousSelection,DataFrame-method}
\alias{previousSelection,MultiAssayExperiment-method}
\title{Automated Selection of Previously Selected Features}
\usage{
\S4method{previousSelection}{matrix}(measurementsTrain, ...)

\S4method{previousSelection}{DataFrame}(
  measurementsTrain,
  classesTrain,
  classifyResult,
  minimumOverlapPercent = 80,
  .iteration,
  verbose = 3
)

\S4method{previousSelection}{MultiAssayExperiment}(measurementsTrain, ...)
}
\arguments{
\item{measurementsTrain}{Either a \code{\link{matrix}}, \code{\link{DataFrame}}
or \code{\link{MultiAssayExperiment}} containing the training data. For a
\code{matrix}, the rows are features, and the columns are samples.}

\item{...}{Variables not used by the \code{matrix} nor the
\code{MultiAssayExperiment} method which are passed into and used by the
\code{DataFrame} method.}

\item{classesTrain}{Do not specify this variable. It is ignored and only used to
create consistency of formal parameters with other feature selection
methods.}

\item{classifyResult}{An existing classification result from which to take
the feature selections from.}

\item{minimumOverlapPercent}{If at least this many selected features can't
be identified in the current data set, then the selection stops with an
error.}

\item{.iteration}{Do not specify this variable. It is set by
\code{\link{runTests}} if this function is being repeatedly called by
\code{runTests}.}

\item{verbose}{Default: 3. A number between 0 and 3 for the amount of
progress messages to give.  This function only prints progress messages if
the value is 3.}
}
\value{
A vector of feature indices, from the most promising features in the
first position to the least promising feature in the last position.
}
\description{
Uses the feature selection of the same cross-validation iteration of a
previous classification for the current classification task.
}
\examples{

  #if(require(sparsediscrim))
  #{
    # Genes 76 to 100 have differential expression.
    genesMatrix <- sapply(1:100, function(sample) rnorm(25, 9, 0.3))
    genesMatrix <- rbind(genesMatrix, t(sapply(1:25, function(sample)
                                      c(rnorm(75, 9, 0.3), rnorm(25, 14, 0.3)))))
    classes <- factor(rep(c("Poor", "Good"), each = 25))
    rownames(genesMatrix) <- paste("Sample", 1:50)
    colnames(genesMatrix) <- paste("Gene", 1:100)                          
    classes <- factor(rep(c("Poor", "Good"), each = 25))

    CVparams <- CrossValParams(permutations = 2, folds = 2)
    result <- runTests(genesMatrix, classes, CVparams, ModellingParams())
    chosenFeatureNames(result)
                       
    # Genes 50 to 74 have differential expression in new data set.
    
    newDataset <- sapply(1:100, function(sample) c(rnorm(25, 9, 0.3)))
    newDataset <- rbind(newDataset, cbind(sapply(1:49, function(sample) rnorm(25, 9, 0.3)),
                                          sapply(1:25, function(sample) rnorm(25, 14, 0.3)),
                                          sapply(1:26, function(sample) rnorm(25, 9, 0.3))))
                                          
    rownames(newDataset) <- rownames(genesMatrix)
    colnames(newDataset) <- colnames(genesMatrix)
    
    selPars <- SelectParams(previousSelection, intermediate = ".iteration", classifyResult = result)
    previousParams <- ModellingParams(selectParams = selPars)                                       
    newerResult <- runTests(newDataset, classes, CVparams, previousParams)
                                     
    # However, only genes 76 to 100 are chosen, because the feature selections are
    # carried over from the first cross-validated classification.
    chosenFeatureNames(newerResult)
  #}  


}
\author{
Dario Strbenac
}
